package com.engine.omron.service.impl;

import com.engine.core.impl.Service;
import com.engine.omron.service.OverTimeService;
import org.apache.tika.utils.StringUtils;
import weaver.conn.RecordSet;
import weaver.general.BaseBean;
import weaver.general.StringUtil;
import weaver.general.Util;

import java.util.HashMap;
import java.util.Map;

public class OverTimeServiceImpl extends Service implements OverTimeService {

    BaseBean basebean = new BaseBean();

    @Override
    public Map<String, Object> checkOverTimeWorkflow(Map<String, Object> params) {
        basebean.writeLog("----------OverTimeServiceImpl checkOverTimeWorkflow Start----------");

        Map<String, Object> result = new HashMap<String, Object>();
        RecordSet rs = new RecordSet();

        try {
            //申请人
            Integer applicant = Util.getIntValue(Util.null2String(params.get("applicant")));
            basebean.writeLog("applicant: " + applicant );

            //申请月份
            String appMonth = Util.null2String(params.get("applicationMonth"));
            basebean.writeLog("appMonth: " + appMonth );

            Integer requestId = Util.getIntValue(Util.null2String(params.get("requestId")));
            basebean.writeLog("requestId: " + requestId );

            if ( applicant == -1 || applicant == 0 ) {
                result.put("code",500);
                result.put("msg","申请人不正确，请更换申请人！");
                return result;
            }

            if ( applicant == 1 ) {
                result.put("code",500);
                result.put("msg","申请人为系统管理员，请确认是否需要更换申请人！");
                return result;
            }

            if ( StringUtil.isEmpty(appMonth)) {
                result.put("code",500);
                result.put("msg","申请月份未填写，请先填写申请月份！");
                return result;
            }

            String overtimeTableName = basebean.getPropValue("omlKq_main","overtimeTableName");
            basebean.writeLog("overtimeTableName: " + overtimeTableName );

            if ( StringUtil.isEmpty( overtimeTableName)) {
                result.put("code",500);
                result.put("msg","请先配置加班申请表名至配置文件！");
                return result;
            }

            Integer number = -1;

            String checkOverTimeSql = "select count(*) as num from " + overtimeTableName + " where jbry = ? and sqyf = ? ";
            basebean.writeLog("checkOverTimeSql: " + checkOverTimeSql);

            rs.executeQuery(checkOverTimeSql, applicant, appMonth);
            while ( rs.next()) {
                number = Util.getIntValue( Util.null2String( rs.getString("num")));
            }
            basebean.writeLog("number: " + number );

            if ( number == 1 ) {//验证当前流程与已有流程是否为同一条
                if ( requestId > -1) {
                    Integer checkReq = -1;
                    String checkRequestIdSql = "select requestid from " + overtimeTableName + " where jbry = ? and sqyf = ? ";
                    rs.executeQuery(checkRequestIdSql, applicant, appMonth);
                    while (rs.next()) {
                        checkReq = Util.getIntValue(Util.null2String(rs.getString("requestid")));
                    }
                    if ( checkReq > -1 && checkReq.equals(requestId) ) {//当前提交流程和流程表中的保存状态流程为同一条
                        result.put("code",200);
                        result.put("msg","可以提交该月份的加班申请。");
                        return result;
                    }
                } else {//流程为新建
                    result.put("code",500);
                    result.put("msg","该人员已经创建或者提交过该月份的加班申请，不可再提交！");
                    return result;
                }

            } else if ( number > 1 ) {
                result.put("code",500);
                result.put("msg","该人员已经提交过该月份的加班申请，不可再提交！");
                return result;
            }

            result.put("code",200);
            result.put("msg","可以提交该月份的加班申请。");
            return result;
        }catch(Exception e){
            basebean.writeLog("OverTimeServiceImpl checkOverTimeWorkflow Exception: " + e);
            result.put("code",500);
            result.put("msg","检查异常");
            return result;
        }
    }
}
